[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / SignatureProof

# Interface: SignatureProof

Interface for signature-based ownership proofs that use cryptographic message signing

## Remarks

Extends the base OwnershipProface to add signature-specific properties:
- Supports multiple signature standards like EIP-191, EIP-712, BIP-137, SIWE
- Includes the cryptographic proof signature string
- Contains an attestation message that was signed
- Records which wallet provider was used for signing

The signature proves ownership by demonstrating control of the private keys
associated with the claimed address.

## See

 - [ProofTypes](../enumerations/ProofTypes.md) For supported signature types
 - [OwnershipProof](OwnershipProof.md) For base proof properties

## Extends

- [`OwnershipProof`](OwnershipProof.md)

## Properties

### address

> **address**: \`$\{string\}:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`address`](OwnershipProof.md#address)

#### Defined in

[types.ts:1061](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1061)

***

### attestation

> **attestation**: `string`

#### Defined in

[types.ts:1095](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1095)

***

### did

> **did**: \`did:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`did`](OwnershipProof.md#did)

#### Defined in

[types.ts:1060](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1060)

***

### proof

> **proof**: `string`

#### Defined in

[types.ts:1094](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1094)

***

### status

> **status**: [`ProofStatus`](../enumerations/ProofStatus.md)

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`status`](OwnershipProof.md#status)

#### Defined in

[types.ts:1059](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1059)

***

### type

> **type**: [`SIWE`](../enumerations/ProofTypes.md#siwe) \| [`SIWX`](../enumerations/ProofTypes.md#siwx) \| [`EIP191`](../enumerations/ProofTypes.md#eip191) \| [`EIP712`](../enumerations/ProofTypes.md#eip712) \| [`EIP1271`](../enumerations/ProofTypes.md#eip1271) \| [`BIP137`](../enumerations/ProofTypes.md#bip137) \| [`BIP322`](../enumerations/ProofTypes.md#bip322) \| [`BIP137_XPUB`](../enumerations/ProofTypes.md#bip137_xpub) \| [`TIP191`](../enumerations/ProofTypes.md#tip191) \| [`ED25519`](../enumerations/ProofTypes.md#ed25519)

#### Overrides

[`OwnershipProof`](OwnershipProof.md).[`type`](OwnershipProof.md#type)

#### Defined in

[types.ts:1082](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1082)

***

### wallet\_provider

> **wallet\_provider**: `string`

#### Defined in

[types.ts:1096](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1096)

***

### xpub?

> `optional` **xpub**: `string`

#### Defined in

[types.ts:1097](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/755adeb79982a453de2ca37df3c78708bdef61f6/src/types.ts#L1097)
